Twitter - velruse.providers.twitter — Velruse 1.1 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Velruse 1.1 documentation »
- Provider Documentation »

# Twitter - `velruse.providers.twitter`

The Twitter provider combines authentication with OAuth authorization. It requires a Twitter Application to have been created to use. Twitter only provides the twitter screen name and id, along with an OAuth access token.

Twitter Developer Links:

- Register a New Twitter Application
- Twitter OAuth API

## Settings

`consumer_key`
  Twitter application consumer key
`consumer_secret`
  Twitter application secret

## POST Parameters

Complete Example:

    <form action="/velruse/twitter/login" method="post">
        <input type="submit" value="Login with Twitter" />
    </form>

## Pyramid API

Twitter Authentication Views

class `TwitterAuthenticationComplete`(profile=None, credentials=None, provider_name=None, provider_type=None)

  Bases: `velruse.AuthenticationComplete`

  Twitter auth complete

`includeme`(config)

`add_twitter_login`(config, consumer_key, consumer_secret, login_path='/login/twitter', callback_path='/login/twitter/callback', name='twitter')

  Add a Twitter login provider to the application.

`add_twitter_login_from_settings`(config, prefix='velruse.twitter.')

### Navigation

- index
- modules |
- next |
- previous |
- Velruse 1.1 documentation »
- Provider Documentation »